searchNodes=[{"doc":"Implementation of the Maybe monad, inspired by Rust's Option type.","ref":"Rustic.Maybe.html","title":"Rustic.Maybe","type":"module"},{"doc":"Boolean AND operation on 2 Maybe monads which returns the right one. iex&gt; Rustic.Maybe . some ( 1 ) ...&gt; |&gt; Rustic.Maybe . and_other ( Rustic.Maybe . some ( 2 ) ) { :some , 2 } iex&gt; Rustic.Maybe . nothing ( ) ...&gt; |&gt; Rustic.Maybe . and_other ( Rustic.Maybe . some ( 2 ) ) :nothing iex&gt; Rustic.Maybe . some ( 1 ) ...&gt; |&gt; Rustic.Maybe . and_other ( Rustic.Maybe . nothing ( ) ) :nothing","ref":"Rustic.Maybe.html#and_other/2","title":"Rustic.Maybe.and_other/2","type":"function"},{"doc":"Maps the value of a non-empty Maybe monad to a new Maybe monad. iex&gt; Rustic.Maybe . some ( 1 ) ...&gt; |&gt; Rustic.Maybe . and_then ( fn n -&gt; Rustic.Maybe . some ( n + 1 ) end ) { :some , 2 } iex&gt; Rustic.Maybe . some ( 1 ) ...&gt; |&gt; Rustic.Maybe . and_then ( fn _ -&gt; :nothing end ) :nothing iex&gt; Rustic.Maybe . nothing ( ) ...&gt; |&gt; Rustic.Maybe . and_then ( fn n -&gt; Rustic.Maybe . some ( n + 1 ) end ) :nothing","ref":"Rustic.Maybe.html#and_then/2","title":"Rustic.Maybe.and_then/2","type":"function"},{"doc":"Returns the Maybe monad only if predicate returns true for its contained value. iex&gt; Rustic.Maybe . some ( 1 ) ...&gt; |&gt; Rustic.Maybe . filter ( fn n -&gt; n &gt; 0 end ) { :some , 1 } iex&gt; Rustic.Maybe . some ( - 1 ) ...&gt; |&gt; Rustic.Maybe . filter ( fn n -&gt; n &gt; 0 end ) :nothing iex&gt; Rustic.Maybe . nothing ( ) ...&gt; |&gt; Rustic.Maybe . filter ( fn n -&gt; n &gt; 0 end ) :nothing","ref":"Rustic.Maybe.html#filter/2","title":"Rustic.Maybe.filter/2","type":"function"},{"doc":"Returns the Maybe monad contained in a Maybe monad, or nothing. iex&gt; Rustic.Maybe . some ( Rustic.Maybe . some ( 1 ) ) ...&gt; |&gt; Rustic.Maybe . flatten ( ) { :some , 1 } iex&gt; Rustic.Maybe . some ( Rustic.Maybe . nothing ( ) ) ...&gt; |&gt; Rustic.Maybe . flatten ( ) :nothing iex&gt; Rustic.Maybe . nothing ( ) ...&gt; |&gt; Rustic.Maybe . flatten ( ) :nothing","ref":"Rustic.Maybe.html#flatten/1","title":"Rustic.Maybe.flatten/1","type":"function"},{"doc":"Check if a value is a Maybe monad. iex&gt; Rustic.Maybe . nothing ( ) |&gt; Rustic.Maybe . is_maybe ( ) true iex&gt; Rustic.Maybe . some ( 1 ) |&gt; Rustic.Maybe . is_maybe ( ) true iex&gt; 1 |&gt; Rustic.Maybe . is_maybe ( ) false","ref":"Rustic.Maybe.html#is_maybe/1","title":"Rustic.Maybe.is_maybe/1","type":"macro"},{"doc":"Check if a value is an empty Maybe monad. iex&gt; Rustic.Maybe . nothing ( ) |&gt; Rustic.Maybe . is_nothing ( ) true iex&gt; Rustic.Maybe . some ( 1 ) |&gt; Rustic.Maybe . is_nothing ( ) false iex&gt; 1 |&gt; Rustic.Maybe . is_nothing ( ) false","ref":"Rustic.Maybe.html#is_nothing/1","title":"Rustic.Maybe.is_nothing/1","type":"macro"},{"doc":"Check if a value is a non-empty Maybe monad. iex&gt; Rustic.Maybe . nothing ( ) |&gt; Rustic.Maybe . is_some ( ) false iex&gt; Rustic.Maybe . some ( 1 ) |&gt; Rustic.Maybe . is_some ( ) true iex&gt; 1 |&gt; Rustic.Maybe . is_some ( ) false","ref":"Rustic.Maybe.html#is_some/1","title":"Rustic.Maybe.is_some/1","type":"macro"},{"doc":"Apply a function to the value of a Maybe monad. iex&gt; Rustic.Maybe . some ( 1 ) ...&gt; |&gt; Rustic.Maybe . map ( fn n -&gt; n + 1 end ) { :some , 2 } iex&gt; Rustic.Maybe . nothing ( ) ...&gt; |&gt; Rustic.Maybe . map ( fn n -&gt; n + 1 end ) :nothing","ref":"Rustic.Maybe.html#map/2","title":"Rustic.Maybe.map/2","type":"function"},{"doc":"Return the default result for an empty Maybe monad, or Apply a function to its value and return the result. iex&gt; Rustic.Maybe . some ( 1 ) ...&gt; |&gt; Rustic.Maybe . map_or ( 3 , fn n -&gt; n + 1 end ) 2 iex&gt; Rustic.Maybe . nothing ( ) ...&gt; |&gt; Rustic.Maybe . map_or ( 3 , fn n -&gt; n + 1 end ) 3","ref":"Rustic.Maybe.html#map_or/3","title":"Rustic.Maybe.map_or/3","type":"function"},{"doc":"Compute the default result for an empty Maybe monad, or Apply a function to its value and return the result. iex&gt; Rustic.Maybe . some ( 1 ) ...&gt; |&gt; Rustic.Maybe . map_or_else ( fn -&gt; 3 end , fn n -&gt; n + 1 end ) 2 iex&gt; Rustic.Maybe . nothing ( ) ...&gt; |&gt; Rustic.Maybe . map_or_else ( fn -&gt; 3 end , fn n -&gt; n + 1 end ) 3","ref":"Rustic.Maybe.html#map_or_else/3","title":"Rustic.Maybe.map_or_else/3","type":"function"},{"doc":"Returns an empty Maybe monad.","ref":"Rustic.Maybe.html#nothing/0","title":"Rustic.Maybe.nothing/0","type":"function"},{"doc":"Transform a Maybe monad into a Result monad, turning nothing into an error. iex&gt; Rustic.Maybe . some ( 1 ) ...&gt; |&gt; Rustic.Maybe . ok_or ( :no_value ) { :ok , 1 } iex&gt; Rustic.Maybe . nothing ( ) ...&gt; |&gt; Rustic.Maybe . ok_or ( :no_value ) { :error , :no_value }","ref":"Rustic.Maybe.html#ok_or/2","title":"Rustic.Maybe.ok_or/2","type":"function"},{"doc":"Transform a Maybe monad into a Result monad turning nothing into a computed error. iex&gt; Rustic.Maybe . some ( 1 ) ...&gt; |&gt; Rustic.Maybe . ok_or_else ( fn -&gt; :no_value end ) { :ok , 1 } iex&gt; Rustic.Maybe . nothing ( ) ...&gt; |&gt; Rustic.Maybe . ok_or_else ( fn -&gt; :no_value end ) { :error , :no_value }","ref":"Rustic.Maybe.html#ok_or_else/2","title":"Rustic.Maybe.ok_or_else/2","type":"function"},{"doc":"Returns the Maybe monad or execute a function returing a Maybe monad. iex&gt; Rustic.Maybe . some ( 1 ) ...&gt; |&gt; Rustic.Maybe . or_else ( fn -&gt; Rustic.Maybe . some ( 2 ) end ) { :some , 1 } iex&gt; Rustic.Maybe . nothing ( ) ...&gt; |&gt; Rustic.Maybe . or_else ( fn -&gt; Rustic.Maybe . some ( 2 ) end ) { :some , 2 } iex&gt; Rustic.Maybe . nothing ( ) ...&gt; |&gt; Rustic.Maybe . or_else ( fn -&gt; Rustic.Maybe . nothing ( ) end ) :nothing","ref":"Rustic.Maybe.html#or_else/2","title":"Rustic.Maybe.or_else/2","type":"function"},{"doc":"Boolean OR operation on 2 Maybe monads which returns the left one. iex&gt; Rustic.Maybe . some ( 1 ) ...&gt; |&gt; Rustic.Maybe . or_other ( Rustic.Maybe . some ( 2 ) ) { :some , 1 } iex&gt; Rustic.Maybe . nothing ( ) ...&gt; |&gt; Rustic.Maybe . or_other ( Rustic.Maybe . some ( 2 ) ) { :some , 2 } iex&gt; Rustic.Maybe . nothing ( ) ...&gt; |&gt; Rustic.Maybe . or_other ( Rustic.Maybe . nothing ( ) ) :nothing","ref":"Rustic.Maybe.html#or_other/2","title":"Rustic.Maybe.or_other/2","type":"function"},{"doc":"Encaspulate a value into a Maybe monad.","ref":"Rustic.Maybe.html#some/1","title":"Rustic.Maybe.some/1","type":"function"},{"doc":"Transform a Maybe monad containing a Result monad to a Result monad containing a Maybe monad. iex&gt; Rustic.Maybe . some ( { :ok , 1 } ) ...&gt; |&gt; Rustic.Maybe . transpose ( ) { :ok , { :some , 1 } } iex&gt; Rustic.Maybe . some ( :ok ) ...&gt; |&gt; Rustic.Maybe . transpose ( ) { :ok , { :some , nil } } iex&gt; Rustic.Maybe . some ( { :error , :no_value } ) ...&gt; |&gt; Rustic.Maybe . transpose ( ) { :error , :no_value } iex&gt; Rustic.Maybe . nothing ( ) ...&gt; |&gt; Rustic.Maybe . transpose ( ) { :ok , :nothing }","ref":"Rustic.Maybe.html#transpose/1","title":"Rustic.Maybe.transpose/1","type":"function"},{"doc":"Get the value of a Maybe monad or raise an exception if it were empty. iex&gt; Rustic.Maybe . some ( 1 ) |&gt; Rustic.Maybe . unwrap! ( ) 1 iex&gt; Rustic.Maybe . nothing ( ) |&gt; Rustic.Maybe . unwrap! ( ) ** (ArgumentError) trying to unwrap an empty Maybe monad","ref":"Rustic.Maybe.html#unwrap!/1","title":"Rustic.Maybe.unwrap!/1","type":"function"},{"doc":"Get the value of a Maybe monad or a default value if it were empty. iex&gt; Rustic.Maybe . some ( 1 ) |&gt; Rustic.Maybe . unwrap_or ( 2 ) 1 iex&gt; Rustic.Maybe . nothing ( ) |&gt; Rustic.Maybe . unwrap_or ( 2 ) 2","ref":"Rustic.Maybe.html#unwrap_or/2","title":"Rustic.Maybe.unwrap_or/2","type":"function"},{"doc":"Get the value of a Maybe monad or compute a default value if it were empty. iex&gt; Rustic.Maybe . some ( 1 ) |&gt; Rustic.Maybe . unwrap_or_else ( fn -&gt; 2 end ) 1 iex&gt; Rustic.Maybe . nothing ( ) |&gt; Rustic.Maybe . unwrap_or_else ( fn -&gt; 2 end ) 2","ref":"Rustic.Maybe.html#unwrap_or_else/2","title":"Rustic.Maybe.unwrap_or_else/2","type":"function"},{"doc":"Boolean XOR operation on 2 Maybe monad which returns some value if and only if one of them is non empty. iex&gt; Rustic.Maybe . some ( 1 ) ...&gt; |&gt; Rustic.Maybe . xor_other ( Rustic.Maybe . some ( 2 ) ) :nothing iex&gt; Rustic.Maybe . nothing ( ) ...&gt; |&gt; Rustic.Maybe . xor_other ( Rustic.Maybe . nothing ( ) ) :nothing iex&gt; Rustic.Maybe . some ( 1 ) ...&gt; |&gt; Rustic.Maybe . xor_other ( Rustic.Maybe . nothing ( ) ) { :some , 1 } iex&gt; Rustic.Maybe . nothing ( ) ...&gt; |&gt; Rustic.Maybe . xor_other ( Rustic.Maybe . some ( 2 ) ) { :some , 2 }","ref":"Rustic.Maybe.html#xor_other/2","title":"Rustic.Maybe.xor_other/2","type":"function"},{"doc":"Describe an Error result.","ref":"Rustic.Maybe.html#t:error/0","title":"Rustic.Maybe.error/0","type":"type"},{"doc":"Describe an empty Maybe monad.","ref":"Rustic.Maybe.html#t:nothing/0","title":"Rustic.Maybe.nothing/0","type":"type"},{"doc":"Describe an Ok result.","ref":"Rustic.Maybe.html#t:ok/0","title":"Rustic.Maybe.ok/0","type":"type"},{"doc":"Describe a Result monad.","ref":"Rustic.Maybe.html#t:result/0","title":"Rustic.Maybe.result/0","type":"type"},{"doc":"Describe a Maybe monad containing some value.","ref":"Rustic.Maybe.html#t:some/0","title":"Rustic.Maybe.some/0","type":"type"},{"doc":"Describe a Maybe monad.","ref":"Rustic.Maybe.html#t:t/0","title":"Rustic.Maybe.t/0","type":"type"},{"doc":"Maybe monad for Elixir inspired by Rust Option type.","ref":"readme.html","title":"Overview","type":"extras"},{"doc":"This package can be installed by adding rustic_maybe to your list of dependencies in mix.exs : def deps do [ { :rustic_maybe , &quot;~&gt; 0.1.0&quot; } ] end","ref":"readme.html#installation","title":"Overview - Installation","type":"extras"},{"doc":"import Rustic.Maybe some ( 1 ) == { :some , 1 } # true nothing ( ) == :nothing # true some ( 1 ) |&gt; unwrap! ( ) # 1 nothing ( ) |&gt; unwrap! ( ) # ** (ArgumentError) trying to unwrap an empty Maybe monad some ( 1 ) |&gt; map ( fn n -&gt; n + 1 end ) # some(2) nothing ( ) |&gt; map ( fn n -&gt; n + 1 end ) # nothing() some ( 1 ) |&gt; and_then ( fn n -&gt; some ( n + 1 ) end ) # some(2) nothing ( ) |&gt; and_then ( fn n -&gt; some ( n + 1 ) end ) # nothing() some ( 1 ) |&gt; or_else ( fn -&gt; some ( 2 ) end ) # some(1) nothing ( ) |&gt; or_else ( fn -&gt; some ( 2 ) end ) # some(2) some ( 1 ) |&gt; filter ( fn n -&gt; n &gt; 0 end ) # some(1) some ( - 1 ) |&gt; filter ( fn n -&gt; n &gt; 0 end ) # nothing() nothing ( ) |&gt; filter ( fn n -&gt; n &gt; 0 end ) # nothing() For more examples, please consult the API reference . With function guards: import Rustic.Maybe def handle_option ( val ) when is_nothing ( val ) do # ... end def handle_option ( val ) when is_some ( val ) do # ... end def handle_result ( val ) do raise ArgumentError , message : &quot; \#{ inspect ( val ) } is not a Maybe monad&quot; end","ref":"readme.html#usage","title":"Overview - Usage","type":"extras"},{"doc":"Rustic.Result is an implementation of the Result monad, inspired by Rust's Result type. Result.Maybe does not depend on Rustic.Result but can still work with its data type: alias Rustic.Result # if you installed it alias Rustic.Maybe Maybe . some ( 1 ) |&gt; Maybe . ok_or ( :no_value ) == Result . ok ( 1 ) # true Maybe . nothing ( ) |&gt; Maybe . ok_or ( :no_value ) == Result . err ( :no_value ) # true Maybe . some ( Result . ok ( 1 ) ) |&gt; Maybe . transpose ( ) == Result . ok ( Maybe . some ( 1 ) ) # true Maybe . some ( Result . err ( :no_value ) ) |&gt; Maybe . transpose ( ) == Result . err ( :no_value ) # true Maybe . nothing ( ) |&gt; Maybe . transpose ( ) == Result . ok ( Maybe . nothing ( ) ) # true For more examples, please consult the API reference .","ref":"readme.html#usage-with-rustic-result","title":"Overview - Usage with Rustic.Result","type":"extras"}]